# -*- coding: utf-8 -*-
"""
Created on Monday February 21 2022

To extract the filling factor, we used n = 4.70e11 cm-2 by fitting the transversal resistivity in the low magnetic field classical Hall regime.

@author: david
"""

import imageio
import matplotlib.pyplot as plt
import warnings
import matplotlib.cbook
from skimage import color
from scipy.optimize import curve_fit
import numpy as np
from scipy.signal import savgol_filter
import scipy.special
import scipy
import glob
import matplotlib as mpl

def sigma(Vxx,Isd,ratio): # in ohm/sq
    return abs((Isd)/((Vxx)/ratio))

#%% loading all the data

dataT = []

filepath = glob.glob(r'./*.txt')
dataT = []
for i in filepath:
    dataT.append(np.loadtxt(i, skiprows = 3 , unpack = True))
    
#%% plotting 

n = 4.71E11
h = 6.62607004*1e-34
e = 1.60217662*1e-19
r0 = 1/(e**2/h)

plt.style.use('seaborn-ticks')
plt.rcParams['figure.autolayout'] = False
plt.rcParams['figure.constrained_layout.use'] = True
plt.rcParams['pdf.fonttype'] = 42
plt.rcParams.update({'font.size': 6})

from matplotlib.pyplot import figure
fig, ax1 = plt.subplots(1,1, figsize = (3.34646,3.34646/2), dpi = 600)

nu = h*(n*1e4)/(e*dataT[0][0])

ax1.plot(nu, dataT[0][1], color = 'black', lw = 1)

ax1.set_xlim(2,20)
ax1.set_ylim(0,110)

ax1.tick_params(labelbottom=True, bottom = True, direction = 'in', width =1, top = True, right =True, length = 4) 
ax1.tick_params(which = 'minor', bottom = True, direction = 'in', width =0.75, top = True, length = 2) 

ax1.set_xlabel('$nu$', size = 8 )
ax1.set_ylabel('$r_{xx}$ ($\Omega$/square)')
ax1.set_xticks(np.arange(4,64,4))
ax1.set_xticks(np.arange(4,64,2), minor = True)
ax1.set_xlim(2,60)
    
    