# -*- coding: utf-8 -*-
"""
Created on Thu Oct  7 12:46:40 2021

@author: david
"""

#Imports
import matplotlib.pyplot as plt
import numpy as np
from scipy.optimize import curve_fit
from scipy.signal import savgol_filter
import glob

#Figures tricks
plt.rcParams['figure.dpi'] = 230 #Note: this is helpuful for high dpi displays such as 4k display on Windows
plt.rcParams['figure.autolayout'] = True
plt.rc('font', size=12)

cmap = plt.cm.get_cmap('Spectral')

# Define percolation function 
def percolation(n,a,np):
    return a*(n-np)**(1.31) 
def lin(x,a,b):
    return a*x + b

#Physical constants

e = 1.60217662*1e-19 # C
h = 6.62606057*1e-34 # m^2 kg/s

#%% importing data

filepath = glob.glob(r'./*.txt')
dataT = []
prova = []
for i in filepath:
    dataT.append(np.loadtxt(i, skiprows = 0 , unpack = True))
    prova.append(i)

order = [0,1]

dataTnew = []
for i in range(len(order)):
    dataTnew.append(dataT[order[i]])
    
dataT = dataTnew
    
#%% getting a cmap
import matplotlib.pyplot as plt
import matplotlib.colors as colors
import numpy as np

def truncate_colormap(cmap, minval=0.0, maxval=1.0, n=100):
    new_cmap = colors.LinearSegmentedColormap.from_list(
        'trunc({n},{a:.2f},{b:.2f})'.format(n=cmap.name, a=minval, b=maxval),
        cmap(np.linspace(minval, maxval, n)))
    return new_cmap

arr = np.linspace(0, 50, 100).reshape((10, 10))
fig, ax = plt.subplots(ncols=2)

cmap = plt.get_cmap('jet')
new_cmap = truncate_colormap(cmap, 0.1, 0.9)
ax[0].imshow(arr, interpolation='nearest', cmap=cmap)
ax[1].imshow(arr, interpolation='nearest', cmap=new_cmap)
plt.show()

colors = new_cmap(np.linspace(0.1,0.95,2))

colors = colors[::-1]

#%% tau_q

e = 1.60217662*1e-19 # C
h = 6.62606057*1e-34 # m^2 kg/s
me = 9.10938356*1e-31 #Kg

o5nm , o7nm, one_nm, W3 , myfab, W5, W7, W8 = [0,1,2,3,4,5,6,7]

Mob , tau_q, n = [0,1,2]

plt.style.use('seaborn-ticks')
plt.rcParams['figure.autolayout'] = False
plt.rcParams['figure.constrained_layout.use'] = True
plt.rcParams['pdf.fonttype'] = 42
plt.rcParams.update({'font.size': 6})
plt.rcParams['axes.edgecolor'] = 'black'
plt.rcParams['axes.linewidth'] = 0.8
from matplotlib.pyplot import figure

figure(figsize = (3.34646/3*0.9,3.34646/2.5), dpi = 600)

aux1 = []
aux2 = []

# for i in [0,1]:
#     for j in range(len(dataT[i][tau_q])):
#         if i==0:
#             aux1.append(dataT[i][tau_q][j])
#         else:
#             aux2.append(dataT[i][tau_q][j])
#     if np.mean(dataT[i][tau_q]) != 0:
#         # plt.errorbar(i*5+ len(dataT[i])/10, np.mean(dataT[i][Mob2])*1e-3, yerr = np.std(dataT[i][Mob2])*1e-3/np.sqrt(len(dataT[i][Mob2])) , marker ='D', color = 'black', capsize = 3, elinewidth =2 , capthick=2 )    #, yerr = np.std(dataT[i][Mob2])*1e-3 
#         print(np.mean(dataT[i][tau_q]) , '+-', np.std(dataT[i][tau_q]))
        
# aux1 = np.array(aux1)
# aux2 = np.array(aux2)

aux1 = e*dataT[0][tau_q]*1e-12/(0.19*me)*1e4
aux2 = e*dataT[1][tau_q]*1e-12/(0.19*me)*1e4

Dingle1 = dataT[0][Mob]/aux1
Dingle2 = dataT[1][Mob]/aux2

plt.boxplot(Dingle1, positions=[0.6], widths = 2, patch_artist=True, boxprops=dict(facecolor=colors[0], linewidth=1), medianprops = dict(color='black', linewidth=1), whiskerprops = dict(color='black', linewidth=1 ), capprops = dict(color='black', linewidth=1) )        
plt.boxplot(Dingle2,positions=[3], widths = 2, patch_artist=True, boxprops=dict(facecolor=colors[1], linewidth=1), medianprops = dict(color='black', linewidth=1), whiskerprops = dict(color='black', linewidth=1 ), capprops = dict(color='black', linewidth=1)) 

eb1=plt.errorbar(0.6, np.mean(Dingle1), yerr = np.std(Dingle1)/np.sqrt(len(Dingle1))*2.576 , marker ='D', color = 'black', capsize = 3, elinewidth =1 , capthick=1,zorder=3, ls = '--', markersize = 4 )    #, yerr = np.std(dataT[i][Mob2])*1e-3 

eb1[-1][0].set_linestyle('--') 

Dingle2= [2.39499703, 2.61847985, 2.31396539, 2.12800935] # I removed the outlier from the mean calculation

eb1=plt.errorbar(3, np.mean(Dingle2), yerr = np.std(Dingle2)/np.sqrt(len(Dingle2))*2.576 , marker ='D', color = 'black', capsize = 3, elinewidth =1 , capthick=1,zorder=3, ls = '--' , markersize = 4 )    #, yerr = np.std(dataT[i][Mob2])*1e-3 

eb1[-1][0].set_linestyle('--') 


print(np.mean(Dingle1) ,'+-', np.std(Dingle1))
print(np.mean(Dingle2) ,'+-', np.std(Dingle2))

plt.tick_params(labelbottom=False, bottom = False, direction = 'in', width =0.8, top = False, right =1, length=5)  
plt.ylabel('Dingle  Ratio $\mu$/$\mu_q$')
plt.xlim(-1.5,5)


